@@ -3,11 +3,51 @@ package checker_test
 import (
 	"testing"
 
+	"github.com/getkin/kin-openapi/openapi3"
 	"github.com/stretchr/testify/require"
 	"github.com/tufin/oasdiff/checker"
 	"github.com/tufin/oasdiff/diff"
 )
 
+// BC: deleting a path without deprecation is breaking
+func TestBreaking_DeletedPath(t *testing.T) {
+	errs := d(t, diff.NewConfig(), 1, 701)
+	require.Len(t, errs, 1)
+	require.Equal(t, checker.APIPathRemovedWithoutDeprecationId, errs[0].GetId())
+	require.Equal(t, "api path removed without deprecation", errs[0].GetUncolorizedText(checker.NewDefaultLocalizer()))
+}
+
+// BC: deleting an operation without deprecation is breaking
+func TestBreaking_DeletedOp(t *testing.T) {
+	s1 := l(t, 1)
+	s2 := l(t, 1)
+
+	s1.Spec.Paths.Value(installCommandPath).Put = openapi3.NewOperation()
+
+	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
+	require.NoError(t, err)
+	errs := checker.CheckBackwardCompatibility(allChecksConfig(), d, osm)
+	require.NotEmpty(t, errs)
+	require.Len(t, errs, 1)
+	require.Equal(t, checker.APIRemovedWithoutDeprecationId, errs[0].GetId())
+	require.Equal(t, "api removed without deprecation", errs[0].GetUncolorizedText(checker.NewDefaultLocalizer()))
+}
+
+// BC: deleting an operation after sunset date is not breaking
+func TestBreaking_DeprecationPast(t *testing.T) {
+
+	s1, err := open(getDeprecationFile("deprecated-past.yaml"))
+	require.NoError(t, err)
+
+	s2, err := open(getDeprecationFile("sunset.yaml"))
+	require.NoError(t, err)
+
+	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
+	require.NoError(t, err)
+	errs := checker.CheckBackwardCompatibility(singleCheckConfig(checker.APIRemovedCheck), d, osm)
+	require.Empty(t, errs)
+}
+
 // BC: deleting an operation before sunset date is breaking
 func TestBreaking_RemoveBeforeSunset(t *testing.T) {
 
@@ -44,6 +84,44 @@ func TestBreaking_DeprecationNoSunset(t *testing.T) {
 	require.Equal(t, checker.INFO, errs[0].GetLevel())
 }
 
+// BC: removing the path without a deprecation policy and without specifying sunset date is not breaking for alpha level
+func TestBreaking_RemovedPathForAlpha(t *testing.T) {
+	s1, err := open(getDeprecationFile("base-alpha-stability.yaml"))
+	require.NoError(t, err)
+	alpha := toJson(t, checker.STABILITY_ALPHA)
+	s1.Spec.Paths.Value("/api/test").Get.Extensions["x-stability-level"] = alpha
+	s1.Spec.Paths.Value("/api/test").Post.Extensions = map[string]interface{}{"x-stability-level": alpha}
+
+	s2, err := open(getDeprecationFile("base-alpha-stability.yaml"))
+	require.NoError(t, err)
+
+	s2.Spec.Paths.Delete("/api/test")
+
+	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
+	require.NoError(t, err)
+	errs := checker.CheckBackwardCompatibility(singleCheckConfig(checker.APIRemovedCheck), d, osm)
+	require.Empty(t, errs)
+}
+
+// BC: removing the path without a deprecation policy and without specifying sunset date is not breaking for draft level
+func TestBreaking_RemovedPathForDraft(t *testing.T) {
+	s1, err := open(getDeprecationFile("base-alpha-stability.yaml"))
+	require.NoError(t, err)
+	draft := toJson(t, checker.STABILITY_DRAFT)
+	s1.Spec.Paths.Value("/api/test").Get.Extensions["x-stability-level"] = draft
+	s1.Spec.Paths.Value("/api/test").Post.Extensions = map[string]interface{}{"x-stability-level": draft}
+
+	s2, err := open(getDeprecationFile("base-alpha-stability.yaml"))
+	require.NoError(t, err)
+
+	s2.Spec.Paths.Delete("/api/test")
+
+	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
+	require.NoError(t, err)
+	errs := checker.CheckBackwardCompatibility(singleCheckConfig(checker.APIRemovedCheck), d, osm)
+	require.Empty(t, errs)
+}
+
 // BC: removing the path without a deprecation policy and without specifying sunset date is breaking for endpoints with non draft/alpha stability level
 func TestBreaking_RemovedPathForAlphaBreaking(t *testing.T) {
 	s1, err := open(getDeprecationFile("base-alpha-stability.yaml"))
@@ -76,6 +154,21 @@ func TestBreaking_RemovedPathForDraftBreaking(t *testing.T) {
 	require.Equal(t, "api path removed without deprecation", errs[0].GetUncolorizedText(checker.NewDefaultLocalizer()))
 }
 
+// BC: deleting a path after sunset date of all contained operations is not breaking
+func TestBreaking_DeprecationPathPast(t *testing.T) {
+
+	s1, err := open(getDeprecationFile("deprecated-path-past.yaml"))
+	require.NoError(t, err)
+
+	s2, err := open(getDeprecationFile("sunset-path.yaml"))
+	require.NoError(t, err)
+
+	d, osm, err := diff.GetWithOperationsSourcesMap(diff.NewConfig(), s1, s2)
+	require.NoError(t, err)
+	errs := checker.CheckBackwardCompatibility(singleCheckConfig(checker.APIRemovedCheck), d, osm)
+	require.Empty(t, errs)
+}
+
 // BC: deleting a path with some operations having sunset date in the future is breaking
 func TestBreaking_DeprecationPathMixed(t *testing.T) {
 
