@@ -6,7 +6,10 @@ import (
 
 const (
 	RequestParameterTypeChangedId                = "request-parameter-type-changed"
+	RequestParameterTypeGeneralizedId            = "request-parameter-type-generalized"
 	RequestParameterPropertyTypeChangedId        = "request-parameter-property-type-changed"
+	RequestParameterPropertyTypeGeneralizedId    = "request-parameter-property-type-generalized"
+	RequestParameterPropertyTypeSpecializedId    = "request-parameter-property-type-specialized"
 	RequestParameterPropertyTypeChangedCommentId = "request-parameter-property-type-changed-warn-comment"
 )
 
@@ -36,9 +39,15 @@ func RequestParameterTypeChangedCheck(diffReport *diff.Diff, operationsSources *
 
 					if !typeDiff.Empty() || !formatDiff.Empty() {
 
+						id := RequestParameterTypeGeneralizedId
+
+						if breakingTypeFormatChangedInRequest(typeDiff, formatDiff, false, schemaDiff) {
+							id = RequestParameterTypeChangedId
+						}
+
 						result = append(result, NewApiChange(
-							RequestParameterTypeChangedId,
-							conditionalError(breakingTypeFormatChangedInRequest(typeDiff, formatDiff, false, schemaDiff), INFO),
+							id,
+							config,
 							[]any{paramLocation, paramName, getBaseType(schemaDiff), getBaseFormat(schemaDiff), getRevisionType(schemaDiff), getRevisionFormat(schemaDiff)},
 							"",
 							operationsSources,
@@ -58,11 +67,11 @@ func RequestParameterTypeChangedCheck(diffReport *diff.Diff, operationsSources *
 
 							if !typeDiff.Empty() || !formatDiff.Empty() {
 
-								level, comment := checkRequestParameterPropertyTypeChanged(typeDiff, formatDiff, schemaDiff)
+								id, comment := checkRequestParameterPropertyTypeChanged(typeDiff, formatDiff, schemaDiff)
 
 								result = append(result, NewApiChange(
-									RequestParameterPropertyTypeChangedId,
-									level,
+									id,
+									config,
 									[]any{paramLocation, paramName, propertyFullName(propertyPath, propertyName), getBaseType(schemaDiff), getBaseFormat(schemaDiff), getRevisionType(schemaDiff), getRevisionFormat(schemaDiff)},
 									comment,
 									operationsSources,
