@@ -5,9 +5,10 @@ import (
 )
 
 const (
-	RequestPropertyPatternRemovedId = "request-property-pattern-removed"
-	RequestPropertyPatternAddedId   = "request-property-pattern-added"
-	RequestPropertyPatternChangedId = "request-property-pattern-changed"
+	RequestPropertyPatternRemovedId     = "request-property-pattern-removed"
+	RequestPropertyPatternAddedId       = "request-property-pattern-added"
+	RequestPropertyPatternChangedId     = "request-property-pattern-changed"
+	RequestPropertyPatternGeneralizedId = "request-property-pattern-generalized"
 )
 
 func RequestPropertyPatternUpdatedCheck(diffReport *diff.Diff, operationsSources *diff.OperationsSourcesMap, config *Config) Changes {
@@ -40,7 +41,7 @@ func RequestPropertyPatternUpdatedCheck(diffReport *diff.Diff, operationsSources
 						if patternDiff.To == "" {
 							result = append(result, NewApiChange(
 								RequestPropertyPatternRemovedId,
-								INFO,
+								config,
 								[]any{patternDiff.From, propName},
 								"",
 								operationsSources,
@@ -51,7 +52,7 @@ func RequestPropertyPatternUpdatedCheck(diffReport *diff.Diff, operationsSources
 						} else if patternDiff.From == "" {
 							result = append(result, NewApiChange(
 								RequestPropertyPatternAddedId,
-								WARN,
+								config,
 								[]any{patternDiff.To, propName},
 								PatternChangedCommentId,
 								operationsSources,
@@ -60,15 +61,18 @@ func RequestPropertyPatternUpdatedCheck(diffReport *diff.Diff, operationsSources
 								path,
 							))
 						} else {
-							level := WARN
+
+							id := RequestPropertyPatternChangedId
 							comment := PatternChangedCommentId
+
 							if patternDiff.To == ".*" {
-								level = INFO
+								id = RequestPropertyPatternGeneralizedId
 								comment = ""
 							}
+
 							result = append(result, NewApiChange(
-								RequestPropertyPatternChangedId,
-								level,
+								id,
+								config,
 								[]any{propName, patternDiff.From, patternDiff.To},
 								comment,
 								operationsSources,
