@@ -17,7 +17,8 @@ const (
 	ERR     Level = 3
 	WARN    Level = 2
 	INFO    Level = 1
-	INVALID Level = 0
+	NONE    Level = 0
+	INVALID Level = -1
 )
 
 func NewLevel(level string) (Level, error) {
@@ -28,6 +29,8 @@ func NewLevel(level string) (Level, error) {
 		return WARN, nil
 	case "INFO", "info":
 		return INFO, nil
+	case "NONE", "none":
+		return NONE, nil
 	}
 	return INVALID, fmt.Errorf("invalid level %s", level)
 }
