@@ -239,6 +239,6 @@ func TestDiff_ComponentCallbacksNil(t *testing.T) {
 }
 
 func TestFilterByRegex_Invalid(t *testing.T) {
-	_, err := diff.Get(&diff.Config{PathFilter: "["}, l(t, 1), l(t, 2))
+	_, err := diff.Get(&diff.Config{MatchPath: "["}, l(t, 1), l(t, 2))
 	require.EqualError(t, err, "failed to compile filter regex \"[\": error parsing regexp: missing closing ]: `[`")
 }
