@@ -36,9 +36,9 @@ func newExamplessDiff() *ExamplesDiff {
 	}
 }
 
-func getExamplesDiff(config *Config, state *state, examples1, examples2 openapi3.Examples) (*ExamplesDiff, error) {
+func getExamplesDiff(config *Config, examples1, examples2 openapi3.Examples) (*ExamplesDiff, error) {
 
-	diff, err := getExamplesDiffInternal(config, state, examples1, examples2)
+	diff, err := getExamplesDiffInternal(config, examples1, examples2)
 	if err != nil {
 		return nil, err
 	}
@@ -50,7 +50,7 @@ func getExamplesDiff(config *Config, state *state, examples1, examples2 openapi3
 	return diff, nil
 }
 
-func getExamplesDiffInternal(config *Config, state *state, examples1, examples2 openapi3.Examples) (*ExamplesDiff, error) {
+func getExamplesDiffInternal(config *Config, examples1, examples2 openapi3.Examples) (*ExamplesDiff, error) {
 
 	if config.IsExcludeExamples() {
 		return nil, nil
@@ -71,7 +71,7 @@ func getExamplesDiffInternal(config *Config, state *state, examples1, examples2
 				return nil, err
 			}
 
-			diff, err := getExampleDiff(config, state, value1, value2)
+			diff, err := getExampleDiff(config, value1, value2)
 			if err != nil {
 				return nil, err
 			}
