@@ -13,12 +13,12 @@ func Test_MergeSpecOK(t *testing.T) {
 	require.NoError(t, err)
 	merged := spec.Spec
 	require.NoError(t, err)
-	require.Equal(t, "string", merged.Components.Schemas["GroupView"].Value.Properties["created"].Value.Type)
-	require.Equal(t, "string", merged.Components.Parameters["groupId"].Value.Schema.Value.Properties["prop1"].Value.Type)
-	require.Equal(t, "boolean", merged.Components.Parameters["groupId"].Value.Schema.Value.Properties["prop2"].Value.Type)
+	require.True(t, merged.Components.Schemas["GroupView"].Value.Properties["created"].Value.Type.Is("string"))
+	require.True(t, merged.Components.Parameters["groupId"].Value.Schema.Value.Properties["prop1"].Value.Type.Is("string"))
+	require.True(t, merged.Components.Parameters["groupId"].Value.Schema.Value.Properties["prop2"].Value.Type.Is("boolean"))
 	require.Empty(t, merged.Components.Parameters["groupId"].Value.Schema.Value.AllOf)
-	require.Equal(t, "string", merged.Paths.Value("/api/v1.0/groups").Patch.RequestBody.Value.Content["application/json"].Schema.Value.Properties["prop1"].Value.Type)
-	require.Equal(t, "boolean", merged.Paths.Value("/api/v1.0/groups").Patch.RequestBody.Value.Content["application/json"].Schema.Value.Properties["prop2"].Value.Type)
+	require.True(t, merged.Paths.Value("/api/v1.0/groups").Patch.RequestBody.Value.Content["application/json"].Schema.Value.Properties["prop1"].Value.Type.Is("string"))
+	require.True(t, merged.Paths.Value("/api/v1.0/groups").Patch.RequestBody.Value.Content["application/json"].Schema.Value.Properties["prop2"].Value.Type.Is("boolean"))
 	require.Empty(t, merged.Paths.Value("/api/v1.0/groups").Patch.RequestBody.Value.Content["application/json"].Schema.Value.AllOf)
 }
 
@@ -32,7 +32,7 @@ func TestMergeSpec_CircularAdditionalPropsWithoutAllOf(t *testing.T) {
 	require.NoError(t, err)
 
 	merged := spec.Spec
-	require.Equal(t, "object", merged.Components.Schemas["BaseSchema"].Value.Properties["prop1"].Value.Type)
+	require.True(t, merged.Components.Schemas["BaseSchema"].Value.Properties["prop1"].Value.Type.Is("object"))
 	require.NotNil(t, merged.Components.Schemas["BaseSchema"].Value.Properties["prop1"].Value.AdditionalProperties.Schema)
 	require.NotNil(t, merged.Components.Schemas["BaseSchema"].Value.Properties["prop1"].Value.AdditionalProperties.Schema.Value)
 
@@ -47,8 +47,8 @@ func TestMergeSpec_MergeCircularAdditionalPropsWithAllOf(t *testing.T) {
 
 	merged := spec.Spec
 	require.Nil(t, merged.Components.Schemas["BaseSchema"].Value.AllOf)
-	require.Equal(t, "string", merged.Components.Schemas["BaseSchema"].Value.Properties["fixedProperty"].Value.Type)
-	require.Equal(t, "object", merged.Components.Schemas["BaseSchema"].Value.Properties["prop1"].Value.Type)
+	require.True(t, merged.Components.Schemas["BaseSchema"].Value.Properties["fixedProperty"].Value.Type.Is("string"))
+	require.True(t, merged.Components.Schemas["BaseSchema"].Value.Properties["prop1"].Value.Type.Is("object"))
 	require.NotNil(t, merged.Components.Schemas["BaseSchema"].Value.Properties["prop1"].Value.AdditionalProperties.Schema)
 	require.NotNil(t, merged.Components.Schemas["BaseSchema"].Value.Properties["prop1"].Value.AdditionalProperties.Schema.Value)
 
@@ -63,7 +63,7 @@ func TestMergeSpec_MergeCircularAdditionalPropsNestedWithinAllOf(t *testing.T) {
 
 	merged := spec.Spec
 	require.Nil(t, merged.Components.Schemas["BaseSchema"].Value.AllOf)
-	require.Equal(t, "object", merged.Components.Schemas["BaseSchema"].Value.Properties["prop1"].Value.Type)
+	require.True(t, merged.Components.Schemas["BaseSchema"].Value.Properties["prop1"].Value.Type.Is("object"))
 	require.NotNil(t, merged.Components.Schemas["BaseSchema"].Value.Properties["prop1"].Value.AdditionalProperties.Schema)
 	require.NotNil(t, merged.Components.Schemas["BaseSchema"].Value.Properties["prop1"].Value.AdditionalProperties.Schema.Value)
 
