@@ -2,8 +2,11 @@ package formatters_test
 
 import (
 	"fmt"
+	"html/template"
 	"testing"
 
+	_ "embed"
+
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"github.com/tufin/oasdiff/checker"
@@ -72,3 +75,13 @@ func TestHtmlFormatter_NotImplemented(t *testing.T) {
 	_, err = htmlFormatter.RenderSummary(nil, formatters.NewRenderOpts())
 	assert.Error(t, err)
 }
+
+//go:embed templates/changelog.html
+var changelogHtml string
+
+func TestExecuteHtmlTemplate_Err(t *testing.T) {
+	tmpl := template.Must(template.New("changelog").Parse(changelogHtml))
+	tmpl.Tree = nil
+	_, err := formatters.ExecuteHtmlTemplate(tmpl, nil, nil)
+	assert.Error(t, err)
+}
