@@ -27,6 +27,7 @@ var formatters = map[Format]Formatter{
 	FormatJSON:          JSONFormatter{},
 	FormatText:          TEXTFormatter{},
 	FormatMarkup:        MarkupFormatter{},
+	FormatMarkdown:      MarkupFormatter{},
 	FormatSingleLine:    SingleLineFormatter{},
 	FormatHTML:          HTMLFormatter{},
 	FormatGithubActions: GitHubActionsFormatter{},
@@ -45,7 +46,7 @@ func Lookup(format string, opts FormatterOpts) (Formatter, error) {
 		return newJSONFormatter(l), nil
 	case FormatText:
 		return newTEXTFormatter(l), nil
-	case FormatMarkup:
+	case FormatMarkup, FormatMarkdown:
 		return newMarkupFormatter(l), nil
 	case FormatSingleLine:
 		return newSingleLineFormatter(l), nil
