@@ -8,7 +8,6 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/oasdiff/telemetry/model"
 	"github.com/stretchr/testify/require"
 	"github.com/tufin/oasdiff/checker"
 	"github.com/tufin/oasdiff/formatters"
@@ -21,15 +20,10 @@ func cmdToArgs(cmd string) []string {
 }
 
 func TestMain(m *testing.M) {
-	setup()
 	code := m.Run()
 	os.Exit(code)
 }
 
-func setup() {
-	os.Setenv(model.EnvNoTelemetry, "1")
-}
-
 func Test_InvalidCmd(t *testing.T) {
 	require.Equal(t, 100, internal.Run(cmdToArgs("oasdiff invalid"), io.Discard, io.Discard))
 }
@@ -297,7 +291,7 @@ func Test_BreakingChangesFlattenCommonParams(t *testing.T) {
 }
 
 func Test_BreakingChangesCaseInsensitiveHeaders(t *testing.T) {
-	require.Zero(t, internal.Run(cmdToArgs("oasdiff breaking ../data/header-case/base.yaml ../data/header-case/revision.yaml --case-insensitive-headers --fail-on ERR"), io.Discard, io.Discard))
+	require.Zero(t, internal.Run(cmdToArgs("oasdiff diff ../data/header-case/base.yaml ../data/header-case/revision.yaml --case-insensitive-headers --fail-on-diff"), io.Discard, io.Discard))
 }
 
 func Test_FlattenCmdOK(t *testing.T) {
